@@ -246,7 +246,7 @@ unsafe_constant: {
     }
     expect: {
         console.log(
-            true.a,
+            void 0,
             false.a,
             null.a,
             (void 0).a
@@ -278,7 +278,7 @@ unsafe_object: {
             o + 1,
             2,
             o.b + 1,
-            1..b + 1
+            NaN
         );
     }
     expect_stdout: true
@@ -365,7 +365,7 @@ unsafe_object_repeated: {
             o + 1,
             2,
             o.b + 1,
-            1..b + 1
+            NaN
         );
     }
     expect_stdout: true
@@ -444,8 +444,8 @@ unsafe_integer_key: {
             2,
             2,
             ({0:1})[1] + 1,
-            1[1] + 1,
-            1["1"] + 1
+            NaN,
+            NaN
         );
     }
     expect_stdout: true
@@ -500,8 +500,8 @@ unsafe_float_key: {
             2,
             2,
             ({2.72:1})[3.14] + 1,
-            1[3.14] + 1,
-            1["3.14"] + 1
+            NaN,
+            NaN
         );
     }
     expect_stdout: true
@@ -635,12 +635,12 @@ unsafe_string_bad_index: {
     }
     expect: {
         console.log(
-            "1234".a + 1,
-            "1234"["a"] + 1,
-            "1234"[3.14] + 1
+            NaN,
+            NaN,
+            NaN
         );
     }
-    expect_stdout: true
+    expect_stdout: "NaN NaN NaN"
 }
 
 prototype_function: {
@@ -820,8 +820,8 @@ unsafe_charAt_noop: {
     }
     expect: {
         console.log(
-            s.charAt(0),
-            "string".charAt(x),
+            s[0],
+            "string"[0 | x],
             (typeof x)[0]
         );
     }
@@ -1124,14 +1124,14 @@ issue_2207_1: {
         console.log(Math.max(3, 6, 2, 7, 3, 4));
         console.log(Math.cos(1.2345));
         console.log(Math.cos(1.2345) - Math.sin(4.321));
-        console.log(Math.pow(Math.PI, Math.E - Math.LN10));
+        console.log(Math.pow(Math.PI, Math.E - Math.LN10).toFixed(15));
     }
     expect: {
         console.log("A");
         console.log(7);
         console.log(Math.cos(1.2345));
         console.log(1.2543732512566947);
-        console.log(1.6093984514472044);
+        console.log("1.609398451447204");
     }
     expect_stdout: true
 }
@@ -1687,3 +1687,73 @@ try_increment: {
     }
     expect_stdout: "1"
 }
+
+unsafe_escaped: {
+    options = {
+        evaluate: true,
+        inline: true,
+        passes: 3,
+        reduce_vars: true,
+        side_effects: true,
+        unsafe: true,
+        unused: true,
+    }
+    input: {
+        (function(a) {
+            console.log(function(index) {
+                return a[index];
+            }(function(term) {
+                return a.indexOf(term);
+            }("PASS")));
+        })([ "PASS" ]);
+    }
+    expect: {
+        console.log("PASS");
+    }
+    expect_stdout: "PASS"
+}
+
+unsafe_string_replace: {
+    options = {
+        evaluate: true,
+        unsafe: true,
+    }
+    input: {
+        "foo".replace("f", function() {
+            console.log("PASS");
+        });
+    }
+    expect: {
+        "foo".replace("f", function() {
+            console.log("PASS");
+        });
+    }
+    expect_stdout: "PASS"
+}
+
+issue_3387_1: {
+    options = {
+        evaluate: true,
+    }
+    input: {
+        console.log(1 + (2 + "3"[4]));
+    }
+    expect: {
+        console.log(1 + (2 + "3"[4]));
+    }
+    expect_stdout: "NaN"
+}
+
+issue_3387_2: {
+    options = {
+        evaluate: true,
+        unsafe: true,
+    }
+    input: {
+        console.log(1 + (2 + "3"[4]));
+    }
+    expect: {
+        console.log(NaN);
+    }
+    expect_stdout: "NaN"
+}
