@@ -1150,7 +1150,7 @@ issue_2620_3: {
 }
 
 issue_2620_4: {
-    rename = true,
+    rename = true
     options = {
         dead_code: true,
         evaluate: true,
@@ -3148,3 +3148,51 @@ issue_3402: {
         "function",
     ]
 }
+
+issue_3439: {
+    options = {
+        inline: true,
+    }
+    input: {
+        console.log(typeof function() {
+            return function(a) {
+                function a() {}
+                return a;
+            }(42);
+        }());
+    }
+    expect: {
+        console.log(typeof function(a) {
+            function a() {}
+            return a;
+        }(42));
+    }
+    expect_stdout: "function"
+}
+
+issue_3444: {
+    options = {
+        inline: true,
+        reduce_vars: true,
+        unused: true,
+    }
+    input: {
+        (function(h) {
+            return f;
+            function f() {
+                g();
+            }
+            function g() {
+                h("PASS");
+            }
+        })(console.log)();
+    }
+    expect: {
+        (function(h) {
+            return function() {
+                void h("PASS");
+            };
+        })(console.log)();
+    }
+    expect_stdout: "PASS"
+}
