@@ -1161,3 +1161,49 @@ collapse_rhs_lhs: {
     }
     expect_stdout: "1 3"
 }
+
+drop_arguments: {
+    options = {
+        pure_getters: "strict",
+        side_effects: true,
+    }
+    input: {
+        (function() {
+            arguments.slice = function() {
+                console.log("PASS");
+            };
+            arguments[42];
+            arguments.length;
+            arguments.slice();
+        })();
+    }
+    expect: {
+        (function() {
+            arguments.slice = function() {
+                console.log("PASS");
+            };
+            arguments.slice();
+        })();
+    }
+    expect_stdout: "PASS"
+}
+
+issue_3427: {
+    options = {
+        assignments: true,
+        collapse_vars: true,
+        inline: true,
+        pure_getters: "strict",
+        sequences: true,
+        side_effects: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        var a;
+        (function(b) {
+            b.p = 42;
+        })(a || (a = {}));
+    }
+    expect: {}
+}
